*****************
Algorithm modules
*****************

TODO

.. automodule:: orion.algo
   :members:

.. toctree::
   :maxdepth: 2
   :caption: Algorithm modules of Oríon

   algo/space
   algo/base
   algo/random
   algo/hyperband
   algo/asha
   algo/tpe
